@@ -1,5 +1,6 @@
 """Some utility functions."""
 
+import sys
 import tempfile
 from pathlib import Path
 
@@ -11,9 +12,9 @@ from jeepney.wrappers import (  # type: ignore
 )
 from PySide2 import QtCore, QtGui, QtWidgets
 
-from normcap import utils
+from normcap import system_info, utils
 from normcap.logger import logger
-from normcap.models import Capture, DisplayManager, Platform, ScreenInfo, SystemInfo
+from normcap.models import Capture, DisplayManager, ScreenInfo
 
 
 class ScreenGrabber:
@@ -21,28 +22,28 @@ class ScreenGrabber:
 
     capture: Capture
 
-    def __call__(self, capture: Capture, system_info: SystemInfo) -> Capture:
+    def __call__(self, capture: Capture) -> Capture:
         """Grab screenshot of supplied region."""
         self.capture = capture
 
         if not isinstance(capture.screen, ScreenInfo):
             raise ValueError("Capture object doesn't contain screen information")
 
-        logger.debug(f"Capturing screen {self.capture.screen}")
-        if (
-            system_info.platform == Platform.LINUX
-            and system_info.display_manager == DisplayManager.WAYLAND
-        ):
-            logger.debug("Using DBUS for screenshot")
-            self.grab_with_dbus()
-        elif system_info.platform == Platform.MACOS:
-            logger.debug("Using QT for screenshot by position")
+        logger.debug("Grab screen: %s", self.capture.screen)
+        if sys.platform == "linux":
+            if system_info.display_manager() == DisplayManager.WAYLAND:
+                self.grab_with_dbus()
+            else:
+                self.grab_with_qt_by_screen()
+                self.crop_to_selection()
+        elif sys.platform == "darwin":
             self.grab_with_qt_by_position()
             self.crop_to_selection()
-        else:
-            logger.debug("Using QT for screenshot by screen")
+        elif sys.platform == "win32":
             self.grab_with_qt_by_screen()
             self.crop_to_selection()
+        else:
+            raise RuntimeError(f"Platform {sys.platform} not supported!")
 
         capture.image.setDevicePixelRatio(1)
         return capture
@@ -52,6 +53,7 @@ class ScreenGrabber:
 
         Works well on MacOS, fails on multi monitor on X11.
         """
+        logger.debug("Use capture method: QT by position")
         screen = QtWidgets.QApplication.screens()[self.capture.screen.index]
         screenshot = screen.grabWindow(
             0,
@@ -68,6 +70,7 @@ class ScreenGrabber:
 
         Works well on X11, fails on multi monitor MacOS.
         """
+        logger.debug("Use capture method: QT by screen")
         screenshot = QtGui.QScreen.grabWindow(
             QtWidgets.QApplication.screens()[self.capture.screen.index], 0
         )
@@ -97,18 +100,21 @@ class ScreenGrabber:
         )
 
         if box.width() <= 10 or box.height() <= 10:
-            logger.debug(f"Region selected is very small: {box}")
+            logger.debug("Region selected is very small: %s", box)
             box.setRect(0, 0, 1, 1)
 
-        logger.debug(f"Screen scale factor: {self.capture.scale_factor}")
-        logger.debug(f"Image devicePixelRatio: {self.capture.image.devicePixelRatio()}")
-        logger.debug(f"Image crop box rect: {box.getRect()}")
+        logger.debug("Screen scale factor: %s", self.capture.scale_factor)
+        logger.debug(
+            "Image devicePixelRatio: %s", self.capture.image.devicePixelRatio()
+        )
+        logger.debug("Image crop box rect: %s", box.getRect())
 
         self.capture.image = self.capture.image.copy(box)
         utils.save_image_in_tempfolder(self.capture.image, postfix="_cropped")
 
     def grab_with_dbus(self):
         """Capture rect of screen on gnome systems using wayland."""
+        logger.debug("Use capture method: DBUS")
 
         class DbusScreenshot(MessageGenerator):
             """Capture screenshot through dbus."""
